@@ -422,13 +422,11 @@ class Cluster:
             frame_values = inspect.getargvalues(frame)[3]
             required_attributes = ["region", "ocp_version"]
             if platform == AWS_OSD_STR:
-                required_attributes.extend(
-                    [
-                        "aws_access_key_id",
-                        "aws_account_id",
-                        "aws_secret_access_key",
-                    ]
-                )
+                required_attributes.extend([
+                    "aws_access_key_id",
+                    "aws_account_id",
+                    "aws_secret_access_key",
+                ])
 
             elif platform == GCP_OSD_STR:
                 required_attributes.append("gcp_service_account")
@@ -606,12 +604,10 @@ class ClusterAddOn(Cluster):
         for param, param_dict in required_parameters.items():
             if param not in user_addon_parameters:
                 if use_api_defaults and param_dict["default_value"]:
-                    _user_parameters.append(
-                        {
-                            "id": param,
-                            "value": param_dict["default_value"],
-                        }
-                    )
+                    _user_parameters.append({
+                        "id": param,
+                        "value": param_dict["default_value"],
+                    })
                 else:
                     missing_parameter.append(param)
 
